
#ifndef _C12_de591_
#define _C12_de591_

#ifdef __cplusplus
extern "C" {
#endif

extern void F649_10768(EIF_REFERENCE, EIF_REFERENCE);
extern void F649_10769(EIF_REFERENCE);
extern void EIF_Minit591(void);

#ifdef __cplusplus
}
#endif

#endif
